@@ -1,18 +1,7 @@
 /*
- * Copyright 2015-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2015 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #include "datamodel.h"
@@ -20,6 +9,7 @@
 #include "modeldataloader.h"
 #include "musiclistenersmanager.h"
 
+#include "models/modelLogging.h"
 
 #include <algorithm>
 
@@ -159,6 +149,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -184,6 +175,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
         case ElisaUtils::Radio:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -207,6 +199,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -241,6 +234,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -250,23 +244,24 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         switch (d->mModelType)
         {
         case ElisaUtils::Track:
-            result = QVariant::fromValue(d->mAllTrackData[index.row()]);
+            result = QVariant::fromValue(static_cast<DataTypes::MusicDataType>(d->mAllTrackData[index.row()]));
             break;
         case ElisaUtils::Radio:
-            result = QVariant::fromValue(d->mAllRadiosData[index.row()]);
+            result = QVariant::fromValue(static_cast<DataTypes::MusicDataType>(d->mAllRadiosData[index.row()]));
             break;
         case ElisaUtils::Album:
-            result = QVariant::fromValue(d->mAllAlbumData[index.row()]);
+            result = QVariant::fromValue(static_cast<DataTypes::MusicDataType>(d->mAllAlbumData[index.row()]));
             break;
         case ElisaUtils::Artist:
-            result = QVariant::fromValue(d->mAllArtistData[index.row()]);
+            result = QVariant::fromValue(static_cast<DataTypes::MusicDataType>(d->mAllArtistData[index.row()]));
             break;
         case ElisaUtils::Genre:
-            result = QVariant::fromValue(d->mAllGenreData[index.row()]);
+            result = QVariant::fromValue(static_cast<DataTypes::MusicDataType>(d->mAllGenreData[index.row()]));
             break;
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -287,6 +282,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Genre:
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             result = QUrl{};
             break;
@@ -314,6 +310,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
         case ElisaUtils::Lyricist:
         case ElisaUtils::Composer:
         case ElisaUtils::FileName:
+        case ElisaUtils::Container:
         case ElisaUtils::Unknown:
             break;
         }
@@ -363,13 +360,15 @@ bool DataModel::isBusy() const
     return d->mIsBusy;
 }
 
-void DataModel::initialize(MusicListenersManager *manager, DatabaseInterface *database,
-                           ElisaUtils::PlayListEntryType modelType, ElisaUtils::FilterType filter,
-                           const QString &genre, const QString &artist, qulonglong databaseId)
+void DataModel::initializeByData(MusicListenersManager *manager, DatabaseInterface *database,
+                                 ElisaUtils::PlayListEntryType modelType, ElisaUtils::FilterType filter,
+                                 const DataTypes::DataType &dataFilter)
 {
-    d->mDatabaseId = databaseId;
-    d->mGenre = genre;
-    d->mArtist = artist;
+    qCDebug(orgKdeElisaModel()) << "DataModel::initialize" << modelType << filter << dataFilter;
+
+    d->mDatabaseId = dataFilter[DataTypes::DatabaseIdRole].toULongLong();
+    d->mGenre = dataFilter[DataTypes::GenreRole].toString();
+    d->mArtist = dataFilter[DataTypes::ArtistRole].toString();
 
     initializeModel(manager, database, modelType, filter);
 }
@@ -432,6 +431,7 @@ void DataModel::initializeModel(MusicListenersManager *manager, DatabaseInterfac
         connect(this, &DataModel::needFrequentlyPlayedData,
                 d->mDataLoader, &ModelDataLoader::loadFrequentlyPlayedData);
         break;
+    case ElisaUtils::FilterByPath:
     case ElisaUtils::UnknownFilter:
         break;
     }
@@ -466,6 +466,7 @@ void DataModel::askModelData()
     case ElisaUtils::FilterByFrequentlyPlayed:
         Q_EMIT needFrequentlyPlayedData(d->mModelType);
         break;
+    case ElisaUtils::FilterByPath:
     case ElisaUtils::UnknownFilter:
         break;
     }
@@ -916,6 +917,22 @@ void DataModel::albumModified(const DataModel::AlbumDataType &modifiedAlbum)
     Q_EMIT dataChanged(index(albumIndex, 0), index(albumIndex, 0));
 }
 
+void DataModel::initialize(MusicListenersManager *manager, DatabaseInterface *database,
+                           ElisaUtils::PlayListEntryType modelType, ElisaUtils::FilterType filter,
+                           const QString &genre, const QString &artist, qulonglong databaseId,
+                           const QUrl &pathFilter)
+{
+    Q_UNUSED(pathFilter)
+
+    qCDebug(orgKdeElisaModel()) << "DataModel::initialize" << modelType << filter << databaseId << genre << artist;
+
+    d->mDatabaseId = databaseId;
+    d->mGenre = genre;
+    d->mArtist = artist;
+
+    initializeModel(manager, database, modelType, filter);
+}
+
 void DataModel::cleanedDatabase()
 {
     beginResetModel();
