@@ -1,18 +1,7 @@
 /*
- * Copyright 2018 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2018 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #include "trackmetadatamodel.h"
@@ -188,6 +177,9 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
         case DataTypes::PlayFrequency:
         case DataTypes::ElementTypeRole:
         case DataTypes::FullDataRole:
+        case DataTypes::IsDirectoryRole:
+        case DataTypes::IsPlayListRole:
+        case DataTypes::FilePathRole:
             break;
         }
         break;
@@ -267,6 +259,9 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
         case DataTypes::PlayFrequency:
         case DataTypes::ElementTypeRole:
         case DataTypes::FullDataRole:
+        case DataTypes::IsDirectoryRole:
+        case DataTypes::IsPlayListRole:
+        case DataTypes::FilePathRole:
             break;
         }
         break;
@@ -546,7 +541,7 @@ void TrackMetadataModel::setDatabase(DatabaseInterface *trackDatabase)
 
 void TrackMetadataModel::deleteRadio()
 {
-    if (mTrackData[DataTypes::DatabaseIdRole]>=0) {
+    if (mTrackData[DataTypes::DatabaseIdRole].toULongLong()) {
         Q_EMIT deleteRadioData(mTrackData[DataTypes::DatabaseIdRole].toULongLong());
     }
 }
