@@ -1,24 +1,12 @@
 /*
- * Copyright 2015-2016 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2015 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef DIDLPARSER_H
 #define DIDLPARSER_H
 
-#include "musicalbum.h"
 #include "musicaudiotrack.h"
 
 #include <QObject>
@@ -99,8 +87,6 @@ public:
 
     const QVector<QString> &newAlbumIds() const;
 
-    const QHash<QString, MusicAlbum> &newAlbums() const;
-
     const QVector<QString> &newMusicTrackIds() const;
 
     const QList<MusicAudioTrack> &newMusicTracks() const;
@@ -147,7 +133,7 @@ private Q_SLOTS:
 
 private:
 
-    void decodeContainerNode(const QDomNode &containerNode, QHash<QString, MusicAlbum> &newData, QVector<QString> &newDataIds);
+    void decodeContainerNode(const QDomNode &containerNode, QHash<QString, MusicAudioTrack> &newData, QVector<QString> &newDataIds);
 
     void decodeAudioTrackNode(const QDomNode &itemNode, QHash<QString, MusicAudioTrack> &newData, QVector<QString> &newDataIds);
 
